@@ -1,10 +1,10 @@
 package Module::Install::DOAP;
 
 use 5.008;
-use parent qw(Module::Install::Base);
+use base qw(Module::Install::Base);
 use strict;
 
-our $VERSION = '0.003';
+our $VERSION = '0.004';
 our $AUTHOR_ONLY = 1;
 
 sub doap_metadata
